function inversionAnimation(rmax, domain, curves)
% inversionAnimation(rmax, [domain, curves]):
% Animates a section of a plane (1/rmax <= r <= rmax) under inversion.
% curves: a row cell array of curves defined on the initial plane that will also undergo
% the inversion.  Each is an inline function that, when passed `domain',
% produces a matrix with a column of `r's and a column of
% `theta's.  This function is very careful to weed out infinite/NAN results
% or those of gigantic absolute value, so don't worry.
% domain: something to pass to the curves (ignored if there are no curves)
figure(1);

for prog=pi/2:-pi/12:-pi/2
    hold off;
    x = inline(['exp(lnr.*sin(' num2str(prog,10) ')).*cos(theta)'],'lnr','theta');
    y = inline(['exp(lnr.*sin(' num2str(prog,10) ')).*sin(theta)'],'lnr','theta');
    z = inline(['lnr.*cos(' num2str(prog,10) ')'],'lnr','theta');
    ezmesh(x,y,z,[-log(rmax),log(rmax),0,2*pi]);
    axis([-rmax rmax -rmax rmax -log(rmax) log(rmax) -log(rmax) log(rmax)]);
    axis manual;
    hold on;
    
    if nargin >= 3
        for curveNum=1:size(curves,2)
            curve = curves{curveNum};
            cpolar1 = curve(domain);
            cr1 = cpolar1(:,1);
            ctheta1 = cpolar1(:,2) + pi.*(cr1<0);
            cr1 = abs(cr1);
            cx2 = real((cr1.^sin(prog)).*cos(ctheta1));
            cy2 = real((cr1.^sin(prog)).*sin(ctheta1));
            cz2 = real(log(cr1).*cos(prog));
            finites = isfinite(cx2).*isfinite(cy2).*isfinite(cz2).*(abs(cx2)<10*rmax).*(abs(cy2)<10*rmax).*(abs(cz2)<10*log(rmax));
            for pt=1:size(finites,1)
                if ~finites(pt)
                    cx2(pt)=NaN;
                    cy2(pt)=NaN;
                    cz2(pt)=NaN;
                end
            end
            plot3(cx2,cy2,cz2+.001,'k-');
            plot3(cx2,cy2,cz2-.001,'k-');
        end
    end
    
    pause(.2);
end
